command

Attribute Macro command 

#[command]
Marks a function as a command.

This is the entry point of a command line app, typically the marked function is main.

Options:

  • name: Name of the command, by default is the executable name.
  • description: Description of the command.
  • usage: Information of the usage of the command.
  • help: Help information about the command.
  • version: Version of the command-line app.

Example:

use clapi::macros::*;

#[command(description="A sample app", version=1.0)]
fn main(){
    println!("Hello World!");
}